==> eiffelstudio-16.05.tar: F_code/C1/an1.h <==

#ifndef _C1_an1_
#define _C1_an1_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1_4(EIF_REFERENCE);
extern EIF_REFERENCE F1_5(EIF_REFERENCE);
extern EIF_BOOLEAN F1_7(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_8(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_10(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);
extern void F1_15(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_16(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_20(EIF_REFERENCE);
extern void F1_23(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,24)
static EIF_REFERENCE F1_24_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_24(EIF_REFERENCE);
extern EIF_REFERENCE F1_25(EIF_REFERENCE);
extern EIF_REFERENCE F1_26(EIF_REFERENCE);
extern void F1_27(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,28)
static EIF_REFERENCE F1_28_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_28(EIF_REFERENCE);
extern void F1_29(EIF_REFERENCE);
extern void F1_30(EIF_REFERENCE);
extern void F1_31(EIF_REFERENCE);
extern EIF_POINTER F1_33(EIF_REFERENCE);
extern EIF_REFERENCE F1_34(EIF_REFERENCE);
extern void EIF_Minit1(void);
extern EIF_REFERENCE F161_2752(EIF_REFERENCE);
extern EIF_REFERENCE F161_2749(EIF_REFERENCE);
extern void F999_10486(EIF_REFERENCE, EIF_REFERENCE);
extern void F2106_20748(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF(EIF_REFERENCE,2749)
extern char *(*R14470[])();
extern char *(*R11[])();
extern char *(*R10913[])();
extern char *(*R16224[])();
extern char *(*R28[])();
extern char *(*R11165[])();

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C1/an1.h <==

#ifndef _C1_an1_
#define _C1_an1_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1_4(EIF_REFERENCE);
extern EIF_REFERENCE F1_5(EIF_REFERENCE);
extern EIF_BOOLEAN F1_7(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_8(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_9(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_10(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);
extern void F1_15(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_16(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_23(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,24)
static EIF_REFERENCE F1_24_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_24(EIF_REFERENCE);
extern EIF_REFERENCE F1_25(EIF_REFERENCE);
extern EIF_REFERENCE F1_26(EIF_REFERENCE);
extern void F1_27(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,28)
static EIF_REFERENCE F1_28_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_28(EIF_REFERENCE);
extern void F1_29(EIF_REFERENCE);
extern void F1_30(EIF_REFERENCE);
extern void F1_31(EIF_REFERENCE);
extern EIF_POINTER F1_33(EIF_REFERENCE);
extern void EIF_Minit1(void);
extern void F965_7908(EIF_REFERENCE, EIF_REFERENCE);
extern void F962_7765(EIF_REFERENCE, EIF_REFERENCE);
extern void F45_1732(EIF_REFERENCE, EIF_REFERENCE);
extern void F45_1729(EIF_REFERENCE);
extern void F158_2899(EIF_REFERENCE, EIF_REFERENCE);
extern char *(*R11[])();
extern char *(*R28[])();
extern char *(*R5559[])();
extern char *(*R4432[])();

#ifdef __cplusplus
}
#endif

#endif
